@@ -19,9 +19,8 @@ from pyiem.nws import ugc, vtec, hvtec
 
 # The AWIPS Product Identifier is supposed to be 6chars as per directive,
 # but in practice it is sometimes something between 4 and 6 chars
-# We do require that the first character be a A-Z one as otherwise this will
-# match the LDM sequence number at the top!
-AFOSRE = re.compile(r"^([A-Z][A-Z0-9]{3,5})\s*\t*$", re.M)
+# We need to be careful this does not match the LDM sequence identifier
+AFOSRE = re.compile(r"^([A-Z0-9]{4,6})\s*\t*$", re.M)
 TIME_FMT = (
     "([0-9:]+) (AM|PM) ([A-Z][A-Z][A-Z]?T) ([A-Z][A-Z][A-Z]) "
     "([A-Z][A-Z][A-Z]) ([0-9]+) ([1-2][0-9][0-9][0-9])"
@@ -497,7 +496,7 @@ class TextProduct:
             nwsli_provider = {}
         self.ugc_provider = ugc_provider
         self.nwsli_provider = nwsli_provider
-        self.unixtext = text.replace("\r\r\n", "\n")
+        self.unixtext = text.replace("\r", "")
         self.sections = self.unixtext.split("\n\n")
         self.afos = None
         # The "truth" timestamp
@@ -749,10 +748,10 @@ class TextProduct:
 
     def parse_afos(self):
         """ Figure out what the AFOS PIL is """
-        # at most, only look at the top four lines
+        # at most, only look at the top four lines, skipping the first
         data = "\n".join(
-            [line.strip() for line in self.sections[0].split("\n")[:4]]
+            [line.strip() for line in self.sections[0].split("\n")[1:4]]
         )
-        tokens = re.findall(r"^([A-Z0-9\s\t]{4,6})$", data, re.M)
+        tokens = AFOSRE.findall(data)
         if tokens:
             self.afos = tokens[0].strip()
