@@ -6,15 +6,16 @@ from pyiem.nws.product import TextProduct, TextProductException
 from pyiem.nws.ugc import ugcs_to_text
 from pyiem.reference import TWEET_CHARS
 from pyiem.nws.products._vtec_util import (
+    _associate_vtec_year,
     _resent_match,
     _do_sql_vtec_new,
     _do_sql_vtec_cor,
     _do_sql_vtec_can,
     _do_sql_vtec_con,
     DEFAULT_EXPIRE_DELTA,
-    list_rows,
     check_dup_ps,
     do_sql_hvtec,
+    _load_database_status,
 )
 
 
@@ -53,6 +54,13 @@ class VTECProduct(TextProduct):
             exec() database calls against.
 
         """
+        # Associate a year to each VTEC found in the product, this informs
+        # which database table to use
+        _associate_vtec_year(self, txn)
+        # Build a pandas dataframe to track what we are doing here.
+        dbdf = _load_database_status(txn, self)
+        dbdf["missed"] = True
+
         for segment in self.segments:
             if len(segment.vtec) > 1 and check_dup_ps(segment):
                 self.warnings.append(
@@ -60,14 +68,14 @@ class VTECProduct(TextProduct):
                     "single phenomena / significance"
                 )
             if segment.giswkt and not segment.vtec:
-                if self.afos[:3] not in ["MWS"]:
+                if self.afos is not None and self.afos[:3] not in ["MWS"]:
                     self.warnings.append(
                         "Product segment has LAT...LON, "
                         "but does not have VTEC?"
                     )
             if not segment.ugcs and segment.vtec:
                 self.warnings.append(
-                    "UGC is missing for segment " "that has VTEC!"
+                    "UGC is missing for segment that has VTEC!"
                 )
                 continue
             if not segment.ugcs:
@@ -79,113 +87,42 @@ class VTECProduct(TextProduct):
                     continue
                 # Send all products to the SBW method in case this segment
                 # should of had a polygon and did not.
-                warning_table = self.which_warning_table(txn, segment, vtec)
-                self.do_sbw_geometry(
-                    txn,
-                    segment,
-                    vtec,
-                    warning_table.replace("warnings_", "sbw_"),
-                )
+                self.do_sbw_geometry(txn, segment, vtec)
                 # Check for Hydro-VTEC stuff
                 if segment.hvtec and segment.hvtec[0].nwsli != "00000":
                     do_sql_hvtec(txn, segment)
 
-                self.do_sql_vtec(txn, segment, vtec, warning_table)
+                self.do_sql_vtec(txn, segment, vtec)
+                if dbdf.empty:
+                    continue
+                for ugc in segment.ugcs:
+                    dbdf.at[
+                        (dbdf["ugc"] == str(ugc))
+                        & (dbdf["phenomena"] == vtec.phenomena)
+                        & (dbdf["significance"] == vtec.significance)
+                        & (dbdf["etn"] == vtec.etn)
+                        & (dbdf["year"] == vtec.year),
+                        "missed",
+                    ] = False
+        if dbdf.empty:
+            return
+        df = dbdf[dbdf["missed"]]
+        # Tropical and Earthquake products with ETNs over 1000 are too complex
+        # to check in this manner, I suppose an office could issue 1000 SVRs,
+        # but alas.  See akrherz/pyIEM#316
+        if df.empty or df["etn"].min() >= 1000:
+            return
+        self.warnings.append(f"Product failed to cover all UGC\n{df}")
 
-    def which_warning_table(self, txn, segment, vtec):
-        """ Figure out which table we should work against """
-        if vtec.action in ["NEW"]:
-            table = f"warnings_{self.db_year}"
-            # Lets piggyback a check to see if this ETN has been reused?
-            # Can this realiably be done?
-            txn.execute(
-                f"SELECT max(updated) from {table} WHERE wfo = %s and "
-                "eventid = %s and significance = %s and phenomena = %s",
-                (vtec.office, vtec.etn, vtec.significance, vtec.phenomena),
-            )
-            row = txn.fetchone()
-            if row["max"] is not None:
-                if (self.valid - row["max"]).total_seconds() > (21 * 86400):
-                    self.warnings.append(
-                        "Possible Duplicated ETN\n"
-                        f"  max(updated) is {row['max']}, "
-                        f"prod.valid is {self.valid}\n  table is {table}\n"
-                        f"  VTEC: {str(vtec)}\n  "
-                        f"product_id: {self.get_product_id()}"
-                    )
-            return table
-        # Lets query the database to look for any matching entries within
-        # the past 3, 10, 31 days, to find with the product_issue was,
-        # which guides the table that the data is stored within
-        for offset in [3, 10, 31]:
-            txn.execute(
-                "SELECT tableoid::regclass as tablename, hvtec_nwsli, "
-                "min(product_issue at time zone 'UTC'), "
-                "max(product_issue at time zone 'UTC') from warnings "
-                "WHERE wfo = %s and eventid = %s and significance = %s and "
-                "phenomena = %s and ((updated > %s and updated <= %s) "
-                "or expire > %s) and status not in ('UPG', 'CAN') "
-                "GROUP by tablename, hvtec_nwsli ORDER by tablename DESC ",
-                (
-                    vtec.office,
-                    vtec.etn,
-                    vtec.significance,
-                    vtec.phenomena,
-                    self.valid - timedelta(days=offset),
-                    self.valid,
-                    self.valid,
-                ),
-            )
-            rows = txn.fetchall()
-            if not rows:
-                continue
-            if len(rows) > 1:
-                # We likely have a flood warning and can use the HVTEC NWSLI
-                # to resolve ambiguity
-                hvtec_nwsli = segment.get_hvtec_nwsli()
-                if hvtec_nwsli:
-                    for row in rows:
-                        if hvtec_nwsli == row["hvtec_nwsli"]:
-                            return row["tablename"]
-
-                self.warnings.append(
-                    (
-                        "VTEC %s product: %s returned %s rows when "
-                        "searching for current table"
-                    )
-                    % (str(vtec), self.get_product_id(), txn.rowcount)
-                )
-            row = rows[0]
-            if row["min"] is not None:
-                year = row["min"].year
-                if row["max"].year != year:
-                    print(
-                        "VTEC Product appears to cross 1 Jan UTC "
-                        f"minyear: {year} maxyear: {row['max'].year} "
-                        f"VTEC: {str(vtec)} productid: {self.get_product_id()}"
-                    )
-                self.db_year = int(row["tablename"].replace("warnings_", ""))
-                return row["tablename"]
-
-        # Give up
-        table = f"warnings_{self.db_year}"
-        if not self.is_correction():
-            self.warnings.append(
-                "Failed to find year of product issuance:\n"
-                f"  VTEC:{str(vtec)}\n  PRODUCT: {self.get_product_id()}\n"
-                f"  defaulting to use table: {table}\n"
-                f"  {list_rows(txn, table, vtec)}"
-            )
-        return table
-
-    def do_sql_vtec(self, txn, segment, vtec, warning_table):
-        """ Persist the non-SBW stuff to the database
+    def do_sql_vtec(self, txn, segment, vtec):
+        """Persist the non-SBW stuff to the database
 
         Arguments:
         txn -- A pyscopg2 transaction
         segment -- A TextProductSegment instance
         vtec -- A vtec instance
         """
+        warning_table = f"warnings_{vtec.year}"
         # If this product is ...RESENT, lets check to make sure we did not
         # already get it
         if self.is_resent() and _resent_match(self, txn, warning_table, vtec):
@@ -208,7 +145,7 @@ class VTECProduct(TextProduct):
                 f"do_sql_vtec() encountered {vtec.action} VTEC status"
             )
 
-    def do_sbw_geometry(self, txn, segment, vtec, sbw_table):
+    def do_sbw_geometry(self, txn, segment, vtec):
         """Storage of Storm Based Warning geometry
 
         The IEM uses a seperate table for the Storm Based Warning geometries.
@@ -226,6 +163,7 @@ class VTECProduct(TextProduct):
         # polygon_end   - Time domain this polygon is valid for exclusive
         # updated       - Product time of this product
 
+        sbw_table = f"sbw_{vtec.year}"
         # Figure out when this polygon begins and ends
         polygon_begin = self.valid
         if vtec.action == "NEW" and vtec.begints is not None:
@@ -339,8 +277,9 @@ class VTECProduct(TextProduct):
             f"tml_direction, tml_sknt, {tml_column}, updated, "
             "waterspouttag, is_emergency, is_pds, floodtag_heavyrain, "
             "floodtag_flashflood, floodtag_damage, floodtag_leeve, "
-            "floodtag_dam, hvtec_nwsli) "
-            "VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s, "
+            "floodtag_dam, hvtec_nwsli, hvtec_severity, hvtec_cause, "
+            "hvtec_record) "
+            "VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,"
             "%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)"
         )
         myargs = (
@@ -374,13 +313,11 @@ class VTECProduct(TextProduct):
             segment.flood_tags.get("LEVEE FAILURE"),
             segment.flood_tags.get("DAM FAILURE"),
             segment.get_hvtec_nwsli(),
+            segment.get_hvtec_severity(),
+            segment.get_hvtec_cause(),
+            segment.get_hvtec_record(),
         )
         txn.execute(sql, myargs)
-        if txn.rowcount != 1:
-            self.warnings.append(
-                f"{vtec.s3()} sbw table insert "
-                f"resulted in {txn.rowcount} rows, should be 1"
-            )
 
         # If this is a CAN, UPG action and single purpose, update expiration
         if vtec.action in ["CAN", "UPG"] and self.is_single_action():
@@ -743,13 +680,17 @@ class VTECProduct(TextProduct):
 
     def get_skip_con(self):
         """ Should this product be skipped from generating jabber messages"""
-        if self.afos[:3] == "FLS" and len(self.segments) > 4:
+        if (
+            self.afos is not None
+            and self.afos[:3] == "FLS"
+            and len(self.segments) > 4
+        ):
             return True
         return False
 
 
 def parser(text, utcnow=None, ugc_provider=None, nwsli_provider=None):
-    """ Helper function that actually converts the raw text and emits an
+    """Helper function that actually converts the raw text and emits an
     VTECProduct instance or returns an exception"""
     prod = VTECProduct(
         text,
