@@ -36,6 +36,7 @@ import cartopy.crs as ccrs
 
 TRACE_VALUE = 0.0001
 TWEET_CHARS = 280
+TWITTER_RESOLUTION_INCH = (12.0, 6.75)
 
 EPSG = {
     5070: ccrs.AlbersEqualArea(
@@ -426,6 +427,7 @@ state_bounds = {
     "OK": [-103.20, 33.42, -94.23, 37.20],
     "OR": [-124.77, 41.79, -116.26, 46.44],
     "PA": [-80.72, 39.52, -74.49, 42.47],
+    "PR": [-67.24, 17.95, -65.59, 18.52],
     "RI": [-72.09, 40.95, -70.92, 42.22],
     "SC": [-83.55, 31.85, -78.35, 35.42],
     "SD": [-104.26, 42.28, -96.24, 46.15],
@@ -433,6 +435,7 @@ state_bounds = {
     "TX": [-106.85, 25.64, -93.31, 36.70],
     "UT": [-114.25, 36.80, -108.84, 42.20],
     "VA": [-83.88, 36.34, -75.04, 39.67],
+    "VI": [-65.16, 17.62, -64.51, 18.46],
     "VT": [-73.64, 42.53, -71.26, 45.22],
     "WA": [-124.93, 45.34, -116.72, 49.20],
     "WI": [-93.09, 42.29, -86.61, 47.20],
@@ -621,6 +624,7 @@ state_fips = {
     40: "OK",
     41: "OR",
     42: "PA",
+    72: "PR",
     44: "RI",
     45: "SC",
     46: "SD",
@@ -629,6 +633,7 @@ state_fips = {
     49: "UT",
     50: "VT",
     51: "VA",
+    78: "VI",
     53: "WA",
     54: "WV",
     55: "WI",
