@@ -1,19 +1,11 @@
 """Testing FFG parsing."""
 
-import psycopg2.extras
 import pytest
 from pyiem.nws.products.ffg import parser as ffgparser
-from pyiem.util import get_dbconn, get_test_file
-
-
-@pytest.fixture
-def dbcursor():
-    """Return a database cursor."""
-    return get_dbconn("postgis").cursor(
-        cursor_factory=psycopg2.extras.DictCursor
-    )
+from pyiem.util import get_test_file
 
 
+@pytest.mark.parametrize("database", ["postgis"])
 def test_ffg(dbcursor):
     """FFG"""
     prod = ffgparser(get_test_file("FFGJAN.txt"))
@@ -21,6 +13,7 @@ def test_ffg(dbcursor):
     assert len(prod.data.index) == 53
 
 
+@pytest.mark.parametrize("database", ["postgis"])
 def test_ffg2(dbcursor):
     """FFGKY"""
     prod = ffgparser(get_test_file("FFGKY.txt"))
@@ -28,6 +21,7 @@ def test_ffg2(dbcursor):
     assert len(prod.data.index) == 113
 
 
+@pytest.mark.parametrize("database", ["postgis"])
 def test_ffgama(dbcursor):
     """FFGAMA"""
     prod = ffgparser(get_test_file("FFGAMA.txt"))
